pub enum LayerDescriptionEnum<F: Field> {
Regular(RegularLayerDescription<F>),
Gate(GateLayerDescription<F>),
IdentityGate(IdentityGateLayerDescription<F>),
MatMult(MatMultLayerDescription<F>),
}Expand description
An enum representing the different types of descriptions for each layer, each description containing the shape information of the corresponding layer.
Variants
Regular(RegularLayerDescription<F>)
The circuit description for a regular layer variant.
Gate(GateLayerDescription<F>)
The circuit description for a gate layer variant.
IdentityGate(IdentityGateLayerDescription<F>)
The circuit description for a identity gate layer variant.
MatMult(MatMultLayerDescription<F>)
The circuit description for a matmult layer variant.